@@ -210,12 +210,14 @@ class SyntaxErrorDetector(BaseDetector):
         results: list[DetectedError] = []
 
         for select in self.query.selects:
+            select = select.strip_subqueries()
+
             if select.ast is None:
                 continue
 
             for table in select.ast.find_all(exp.Table):
-                table_name = util.normalize_ast_table_real_name(table)
-                schema_name = util.normalize_ast_schema_name(table)
+                table_name = util.ast.table.get_real_name(table)
+                schema_name = util.ast.table.get_schema(table)
 
                 if schema_name:
                     # Fully qualified table (schema.table)
@@ -248,12 +250,14 @@ class SyntaxErrorDetector(BaseDetector):
         results: list[DetectedError] = []
 
         for select in self.query.selects:
+            select = select.strip_subqueries()
+
             if select.ast is None:
                 continue
 
             for column in select.ast.find_all(exp.Column):
-                column_name = util.normalize_ast_column_name(column)
-                table_name = util.normalize_ast_column_table(column)
+                column_name = util.ast.column.get_name(column)
+                table_name = util.ast.column.get_table(column)
 
                 possible_matches = []
 
@@ -286,7 +290,13 @@ class SyntaxErrorDetector(BaseDetector):
         results: list[DetectedError] = []
 
         # standard_functions = {
-        known_aggregate_functions = {'SUM', 'AVG', 'COUNT', 'MIN', 'MAX', 'IN', 'EXISTS', 'ANY', 'ALL', 'COALESCE', 'NULLIF', 'CAST', 'CONVERT'}
+        known_aggregate_functions = {
+            'SUM', 'AVG', 'COUNT', 'MIN', 'MAX',
+            'IN', 'EXISTS', 'ANY', 'ALL',
+            'COALESCE', 'NULLIF', 'CAST', 'CONVERT',
+            'UPPER', 'LOWER', 'LENGTH', 'SUBSTRING',
+            'NOW', 'CURRENT_DATE', 'CURRENT_TIME', 'CURRENT_TIMESTAMP',
+        }
         user_defined_functions = set() # TODO: self.catalog.functions
 
         all_functions = known_aggregate_functions.union(user_defined_functions)
@@ -327,14 +337,16 @@ class SyntaxErrorDetector(BaseDetector):
         results: set[DetectedError] = set()     # use a set to avoid applying the same correction multiple times
 
         for select in self.query.selects:
+            select = select.strip_subqueries()
+
             if select.ast is None:
                 continue
 
             for table in select.ast.find_all(exp.Table):
                 table = deepcopy(table)  # avoid modifying the original AST until we are sure we want to apply the correction
                 table_str = table.sql()
-                table_name = util.normalize_ast_table_real_name(table)
-                schema_name = util.normalize_ast_schema_name(table)
+                table_name = util.ast.table.get_real_name(table)
+                schema_name = util.ast.table.get_schema(table)
 
                 if schema_name:
                     # Fully qualified table (schema.table)
@@ -382,14 +394,16 @@ class SyntaxErrorDetector(BaseDetector):
         results: set[DetectedError] = set()    # use a set to avoid applying the same correction multiple times
 
         for select in self.query.selects:
+            select = select.strip_subqueries()
+
             if select.ast is None:
                 continue
 
             for column in select.ast.find_all(exp.Column):
                 column = deepcopy(column)  # avoid modifying the original AST until we are sure we want to apply the correction
                 column_str = column.sql()
-                column_name = util.normalize_ast_column_name(column)
-                table_name = util.normalize_ast_column_table(column)
+                column_name = util.ast.column.get_name(column)
+                table_name = util.ast.column.get_table(column)
 
                 found = False
 
@@ -791,8 +805,8 @@ class SyntaxErrorDetector(BaseDetector):
 
             def get_column_name(col: exp.Column | exp.Alias) -> tuple[str, str]:
                 '''Return normalized column name and alias. If no alias, both are the same.'''
-                col_name = util.normalize_ast_column_real_name(col)
-                col_alias = util.normalize_ast_column_name(col)
+                col_name = util.ast.column.get_real_name(col)
+                col_alias = util.ast.column.get_name(col)
                 return col_name, col_alias
 
             for col in select.ast.expressions:
@@ -940,7 +954,7 @@ class SyntaxErrorDetector(BaseDetector):
         '''
         results: list[DetectedError] = []
 
-        clause_keywords = {'SELECT', 'FROM', 'WHERE', 'GROUP BY', 'HAVING', 'ORDER BY', 'LIMIT', 'JOIN', 'ON'}
+        clause_keywords = {'SELECT', 'FROM', 'WHERE', 'GROUP BY', 'HAVING', 'ORDER BY', 'LIMIT', 'OFFSET'}
         
         for select in self.query.selects:
             stripped = select.strip_subqueries()
