@@ -1,5 +1,5 @@
 from sql_error_categorizer.detectors import Detector
-from sql_error_categorizer import load_catalog, build_catalog, SyntaxErrorDetector, SemanticErrorDetector, LogicalErrorDetector, ComplicationDetector
+from sql_error_categorizer import load_catalog, build_catalog_from_postgres, SyntaxErrorDetector, SemanticErrorDetector, LogicalErrorDetector, ComplicationDetector
 
 def make_catalog(file: str) -> None:
     '''Utility function to build a catalog from a source file'''
@@ -7,7 +7,7 @@ def make_catalog(file: str) -> None:
     with open(f'datasets/sql/{file}.sql') as f:
         content = f.read()
 
-    cat = build_catalog(content, hostname='localhost', port=5432, user='postgres', password='password', schema=file, create_temp_schema=True)
+    cat = build_catalog_from_postgres(content, hostname='localhost', port=5432, user='postgres', password='password', schema=file, create_temp_schema=True)
 
     cat.save_json(f'datasets/catalogs/{file}.json')
 
